package com.persagy.apm.alarmservice.alarmrecord.controller;

import com.persagy.apm.alarmservice.alarmrecord.model.dto.*;
import com.persagy.apm.alarmservice.alarmrecord.model.vo.AlarmRecordIdsItem;
import com.persagy.apm.alarmservice.alarmrecord.model.vo.AlarmRecordItem;
import com.persagy.apm.alarmservice.alarmrecord.model.vo.AlarmRecordListItem;
import com.persagy.apm.common.response.CommonResult;
import com.persagy.apm.common.response.PageList;
import com.persagy.apm.common.utils.ResultHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.ArrayList;
import java.util.List;

/**
 * 报警记录控制层
 * @author lixing
 * @version V1.0 2021-09-08 22:30:38
 */
@Api(tags = "报警记录") 
@Validated
@RestController
@RequestMapping("alarm_records")
public class AlarmRecordController {

	@ApiOperation(value = "当前报警列表")
	@PostMapping("/current_list")
	public CommonResult<PageList<AlarmRecordListItem>> queryCurrentAlarmRecord(
	        @Valid @RequestBody PageQueryAlarmRecordDTO pageQueryAlarmRecordDTO) {
        List<AlarmRecordListItem> resultList = new ArrayList<>();
        return ResultHelper.multi(resultList);
	}

    @ApiOperation(value = "历史报警列表")
    @PostMapping("/history_list")
    public CommonResult<PageList<AlarmRecordListItem>> queryHistoryAlarmRecord(
            @Valid @RequestBody PageQueryAlarmRecordDTO pageQueryAlarmRecordDTO) {
        List<AlarmRecordListItem> resultList = new ArrayList<>();
        return ResultHelper.multi(resultList);
    }

    @ApiOperation(value = "已忽略报警列表")
    @PostMapping("/ignored_list")
    public CommonResult<PageList<AlarmRecordListItem>> queryIgnoredAlarmRecord(
            @Valid @RequestBody PageQueryAlarmRecordDTO pageQueryAlarmRecordDTO) {
        List<AlarmRecordListItem> resultList = new ArrayList<>();
        return ResultHelper.multi(resultList);
    }

    @ApiOperation(value = "关闭报警")
    @PostMapping("/close")
    public CommonResult<AlarmRecordIdsItem> closeAlarmRecord(
            @Valid @RequestBody CloseAlarmRecordDTO closeAlarmRecordDTO) {
        AlarmRecordIdsItem alarmRecordIdsItem = new AlarmRecordIdsItem();
        return ResultHelper.single(alarmRecordIdsItem);
    }

    @ApiOperation(value = "转工单")
    @PostMapping("/convert_work_order")
    public CommonResult<AlarmRecordIdsItem> alarmRecordConvertWorkOrder(
            @Valid @RequestBody AlarmRecordConvertWorkOrderDTO alarmRecordConvertWorkOrderDTO) {
        AlarmRecordIdsItem alarmRecordIdsItem = new AlarmRecordIdsItem();
        return ResultHelper.single(alarmRecordIdsItem);
    }

    @ApiOperation(value = "忽略")
    @PostMapping("/ignore")
    public CommonResult<AlarmRecordIdsItem> ignoreAlarmRecord(
            @Valid @RequestBody IgnoreAlarmRecordDTO ignoreAlarmRecordDTO) {
        AlarmRecordIdsItem alarmRecordIdsItem = new AlarmRecordIdsItem();
        return ResultHelper.single(alarmRecordIdsItem);
    }

    @ApiOperation(value = "报警详情")
    @PostMapping("/get")
    public CommonResult<AlarmRecordItem> getAlarmRecord(
            @Valid @RequestBody GetAlarmRecordDTO getAlarmRecordDTO) {
        AlarmRecordItem alarmRecordItem = new AlarmRecordItem();
        return ResultHelper.single(alarmRecordItem);
    }

    @ApiOperation(value = "下载")
    @PostMapping("/download")
    public CommonResult downloadAlarmRecord(
            @Valid @RequestBody DownloadAlarmRecordDTO downloadAlarmRecordDTO) {
        return ResultHelper.success();
    }
}

