package com.persagy.apm.alarmservice.group.alarmrule.service.impl;

import com.persagy.apm.alarmservice.alarmcondition.model.dto.AddAlarmConditionDTO;
import com.persagy.apm.alarmservice.alarmcondition.service.IAlarmConditionService;
import com.persagy.apm.common.configuration.DataUtils;
import com.persagy.apm.common.context.AppContext;
import com.persagy.apm.alarmservice.group.alarmrule.dao.GroupAlarmRuleMapper;
import com.persagy.apm.alarmservice.group.alarmrule.service.IGroupAlarmRuleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.apache.commons.lang.StringUtils;
import com.persagy.apm.common.constant.enums.ValidEnum;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.persagy.apm.alarmservice.group.alarmrule.model.*;
import com.persagy.apm.alarmservice.group.alarmrule.model.dto.*;
import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.google.common.base.CaseFormat;
import com.persagy.apm.common.model.dto.Sort;
import org.springframework.util.CollectionUtils;

/**
 * 集团报警规则(GroupAlarmRule) service层
 *
 * @author lixing
 * @version V1.0 2021-09-08 22:35:45
 */
@Service
public class GroupAlarmRuleServiceImpl extends ServiceImpl<GroupAlarmRuleMapper, GroupAlarmRule> 
    implements IGroupAlarmRuleService {
    @Autowired
    private IAlarmConditionService alarmConditionService;
    /**
    * 创建集团报警规则
    * @return 集团报警规则主键
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public String createGroupAlarmRule(AddGroupAlarmRuleDTO addGroupAlarmRuleDTO) {
        GroupAlarmRule groupAlarmRule = ConvertGroupAlarmRuleTool.INSTANCE.convertAddDto2Entity(addGroupAlarmRuleDTO);
        AddAlarmConditionDTO alarmCondition = addGroupAlarmRuleDTO.getAlarmCondition();
        String alarmConditionId = alarmConditionService.createAlarmCondition(alarmCondition);
        // 设置默认值
        groupAlarmRule.setAlarmConditionId(alarmConditionId);
        setDefaultValue(groupAlarmRule);
        save(groupAlarmRule);
        return groupAlarmRule.getId();
    }
    
    /**
     * 如果某些字段没有赋值，使用默认的值
     *
     * @param groupAlarmRule 集团报警规则实体
     * @author lixing
     * @version V1.0 2021/3/12 12:29 下午
     */
    private void setDefaultValue(GroupAlarmRule groupAlarmRule) {
        groupAlarmRule.setCreator(AppContext.getContext().getAccountId());
        groupAlarmRule.setId(DataUtils.getUUID());
        // todo 其他默认的属性
        
    }
    
    /**
    * 集团报警规则详情
    * @param id 主键
    * @return 部门do类
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public GroupAlarmRule queryGroupAlarmRuleDetail(String id) {
        GroupAlarmRule groupAlarmRule = getById(id);
        if (groupAlarmRule == null) {
            throw new IllegalArgumentException("查看GroupAlarmRule详情时发生异常，找不到要查看的记录，id=" + id);
        }
        return groupAlarmRule;
    }
    
    /**
    * 更新集团报警规则
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public void updateGroupAlarmRule(UpdateGroupAlarmRuleDTO updateGroupAlarmRuleDTO) {
        GroupAlarmRule groupAlarmRule = getById(updateGroupAlarmRuleDTO.getId());
        groupAlarmRule = ConvertGroupAlarmRuleTool.INSTANCE.convertUpdateDto2Entity(groupAlarmRule, updateGroupAlarmRuleDTO);
        groupAlarmRule.setModifier(AppContext.getContext().getAccountId());
        updateById(groupAlarmRule);
    }
    
    /**
     * 校验集团报警规则是否可删除
     *
     * @param id 集团报警规则主键
     * @return 集团报警规则do类
     * @author lixing
     * @version V1.0 2021-09-08 22:35:45
     */
    public GroupAlarmRule checkDeletable(String id) {
        if (id == null) {
            throw new IllegalArgumentException("删除GroupAlarmRule时发生异常，主键为空");
        }

        GroupAlarmRule groupAlarmRule = getById(id);

        if (groupAlarmRule == null) {
            throw new IllegalArgumentException("删除GroupAlarmRule时发生异常，找不到要删除的数据，id:" + id);
        }

        return groupAlarmRule;
    }
    
    /**
    * 删除集团报警规则
    * @param id 主键
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public void deleteGroupAlarmRule(String id) {
        // 校验是否可删除
        GroupAlarmRule groupAlarmRule = checkDeletable(id);

        groupAlarmRule.setValid(ValidEnum.FALSE.getType());
        updateById(groupAlarmRule);
    }
    
    /**
    * 查询集团报警规则
    * @return List<GroupAlarmRule>
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public List<GroupAlarmRule> queryGroupAlarmRuleList(QueryGroupAlarmRuleDTO queryGroupAlarmRuleDTO) {
        QueryWrapper<GroupAlarmRule> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(GroupAlarmRule.PROP_VALID, ValidEnum.TRUE.getType());
        // 默认按创建时间倒序排序
        queryWrapper.orderBy(true, false, GroupAlarmRule.PROP_CREATIONTIME);
        
        if (queryGroupAlarmRuleDTO != null) {
                                
            // todo 需判断使用like还是eq
            if (StringUtils.isNotEmpty(queryGroupAlarmRuleDTO.getGroupId())) {
                queryWrapper.like(GroupAlarmRule.PROP_GROUP_ID, queryGroupAlarmRuleDTO.getGroupId());
            }
                                        
            // todo 需判断使用like还是eq
            if (StringUtils.isNotEmpty(queryGroupAlarmRuleDTO.getAlarmItemCode())) {
                queryWrapper.like(GroupAlarmRule.PROP_ALARM_ITEM_CODE, queryGroupAlarmRuleDTO.getAlarmItemCode());
            }
                                        
            // todo 需判断使用like还是eq
            if (StringUtils.isNotEmpty(queryGroupAlarmRuleDTO.getAlarmConditionId())) {
                queryWrapper.like(GroupAlarmRule.PROP_ALARM_CONDITION_ID, queryGroupAlarmRuleDTO.getAlarmConditionId());
            }
                                            
        }
        
        return list(queryWrapper);
    }
    
    /**
    * 分页查询集团报警规则
    * @return IPage<GroupAlarmRule>
    * @author lixing
    * @version V1.0 2021-09-08 22:35:45
    */
    @Override
    public IPage<GroupAlarmRule> pageQueryGroupAlarmRule(PageQueryGroupAlarmRuleDTO pageQueryGroupAlarmRuleDTO) {
        QueryWrapper<GroupAlarmRule> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(GroupAlarmRule.PROP_VALID, ValidEnum.TRUE.getType());
        // 这里认为pageQueryDTO是经过校验的，肯定包含分页信息
        IPage<GroupAlarmRule> pageParam = new Page<>(pageQueryGroupAlarmRuleDTO.getPage(), pageQueryGroupAlarmRuleDTO.getSize(),true);
        // 排序信息
        if(CollectionUtils.isEmpty(pageQueryGroupAlarmRuleDTO.getOrders())){
            // 默认按创建时间倒序排序
            queryWrapper.orderBy(true, false, GroupAlarmRule.PROP_CREATIONTIME);
        }else {
            List<Sort> orders = pageQueryGroupAlarmRuleDTO.getOrders();
            for(Sort sort: orders) {
                // 将驼峰转换为下划线格式
                sort.setColumn(CaseFormat.LOWER_CAMEL.to(CaseFormat.LOWER_UNDERSCORE,sort.getColumn()));
                queryWrapper.orderBy(true, sort.isAsc(), sort.getColumn());
            }
        }
                
        // todo 需判断使用like还是eq
        if (StringUtils.isNotEmpty(pageQueryGroupAlarmRuleDTO.getGroupId())) {
            queryWrapper.like(GroupAlarmRule.PROP_GROUP_ID, pageQueryGroupAlarmRuleDTO.getGroupId());
        }
                            
        // todo 需判断使用like还是eq
        if (StringUtils.isNotEmpty(pageQueryGroupAlarmRuleDTO.getAlarmItemCode())) {
            queryWrapper.like(GroupAlarmRule.PROP_ALARM_ITEM_CODE, pageQueryGroupAlarmRuleDTO.getAlarmItemCode());
        }
                            
        // todo 需判断使用like还是eq
        if (StringUtils.isNotEmpty(pageQueryGroupAlarmRuleDTO.getAlarmConditionId())) {
            queryWrapper.like(GroupAlarmRule.PROP_ALARM_CONDITION_ID, pageQueryGroupAlarmRuleDTO.getAlarmConditionId());
        }
                                    
        return getBaseMapper().selectPage(pageParam, queryWrapper);
    }
}
