package com.persagy.apm.alarmservice.project.alarmrule.controller;

import com.persagy.apm.alarmservice.project.alarmrule.service.IProjectAlarmRuleService;

import org.springframework.beans.factory.annotation.Autowired;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.persagy.apm.alarmservice.project.alarmrule.model.*;
import com.persagy.apm.alarmservice.project.alarmrule.model.vo.*;
import com.persagy.apm.alarmservice.project.alarmrule.model.dto.*;
import com.persagy.apm.common.response.*;
import com.persagy.apm.common.utils.ResultHelper;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import javax.validation.Valid;
import java.util.List;

/**
 * 项目报警规则控制层
 * @author lixing
 * @version V1.0 2021-09-08 22:46:16
 */
@Api(tags = "项目报警规则") 
@Validated
@RestController
@RequestMapping("projectAlarmRules")
public class ProjectAlarmRuleController {
    @Autowired
    private IProjectAlarmRuleService projectAlarmRuleService;

	@ApiOperation(value = "创建项目报警规则")
	@PostMapping("/create")
	public CommonResult<ApmResponseUpsertVO> createProjectAlarmRule(
	        @Valid @RequestBody AddProjectAlarmRuleDTO addProjectAlarmRuleDTO) {
        String id = projectAlarmRuleService.createProjectAlarmRule(addProjectAlarmRuleDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(id));
	}
	
	@ApiOperation(value = "项目报警规则详情")
    @PostMapping("/get")
    public CommonResult<ProjectAlarmRuleItemVO> queryProjectAlarmRuleDetail(
            @Valid @RequestBody QueryProjectAlarmRuleDetailDTO queryProjectAlarmRuleDetailDTO) {
        ProjectAlarmRule projectAlarmRule = projectAlarmRuleService.queryProjectAlarmRuleDetail(queryProjectAlarmRuleDetailDTO.getId());
        ProjectAlarmRuleItemVO projectAlarmRuleItemVO = ConvertProjectAlarmRuleTool.INSTANCE.convert2ResponseItemDTO(projectAlarmRule);
        return ResultHelper.single(projectAlarmRuleItemVO);
    }


    @ApiOperation(value = "更新项目报警规则")
    @PostMapping("/update")
    public CommonResult<ApmResponseUpsertVO> updateProjectAlarmRule(
            @Valid @RequestBody UpdateProjectAlarmRuleDTO updateProjectAlarmRuleDTO) {
        projectAlarmRuleService.updateProjectAlarmRule(updateProjectAlarmRuleDTO);
        return ResultHelper.single(new ApmResponseUpsertVO(updateProjectAlarmRuleDTO.getId()));
    }


    @ApiOperation(value = "删除项目报警规则")
    @PostMapping("/delete")
    public CommonResult deleteProjectAlarmRule(
            @RequestBody @Valid DeleteProjectAlarmRuleDTO deleteProjectAlarmRuleDTO) {
        projectAlarmRuleService.deleteProjectAlarmRule(deleteProjectAlarmRuleDTO.getId());
        return ResultHelper.success();
    }


    @ApiOperation(value = "项目报警规则列表")
    @PostMapping("/query")
    public CommonResult<PageList<ProjectAlarmRuleListItemVO>> queryProjectAlarmRule(
            @Valid @RequestBody QueryProjectAlarmRuleDTO queryProjectAlarmRuleDTO) {
        List<ProjectAlarmRule> projectAlarmRuleList = projectAlarmRuleService.queryProjectAlarmRuleList(queryProjectAlarmRuleDTO);
        List<ProjectAlarmRuleListItemVO> resultList = ConvertProjectAlarmRuleTool.INSTANCE.convert2List(projectAlarmRuleList);
        return ResultHelper.multi(resultList);
    }
    
    //@ApiOperation(value = "项目报警规则列表, 分页查询")
    //@PostMapping("/query")
    //public CommonResult<PageList<ProjectAlarmRuleListItemVO>> queryProjectAlarmRule(
    //        @Valid @RequestBody PageQueryProjectAlarmRuleDTO pageQueryProjectAlarmRuleDTO) {
    //    IPage<ProjectAlarmRule> pagedList = projectAlarmRuleService.pageQueryProjectAlarmRule(pageQueryProjectAlarmRuleDTO);
    //    IPage<ProjectAlarmRuleListItemVO> pagedResultList = pagedList.convert(item -> {
    //        try {
    //           return ConvertProjectAlarmRuleTool.INSTANCE.convert2ResponseListItemDTO(item);
    //        } catch (Exception e) {
    //            throw new IllegalArgumentException("分页查询，ProjectAlarmRule实体类转换为列表对象发生异常", e);
    //        }
    //    });
    //    return ResultHelper.multi(pagedResultList);
    //}
}

